@@ -5,7 +5,6 @@ from .defaults import ALLOWED_ATTRIBUTES, ALLOWED_TAGS, ALLOWED_STYLES, STRIP_TA
 
 def safe_html(html):
     html = html or ''
-    linkified_html = bleach.linkify(html)
-    cleaned_html = bleach.clean(linkified_html, tags=ALLOWED_TAGS, attributes=ALLOWED_ATTRIBUTES,
+    cleaned_html = bleach.clean(html, tags=ALLOWED_TAGS, attributes=ALLOWED_ATTRIBUTES,
                                 styles=ALLOWED_STYLES, strip=STRIP_TAGS)
-    return cleaned_html
+    return bleach.linkify(cleaned_html)
